import {select, csv, scaleLinear, extent, axisLeft, axisBottom, format, scaleTime, line, curveBasis} from 'd3';

const svg = select('svg');
const circle = svg.append('circle');

const width = +(svg.attr('width'));
const height = +(svg.attr('height'));

const render = data => {
  const title = 'Scatter Plot Of SuspectedCount';
  const xValue = d => d.Time;
  const xAxisLabel = 'Time';
  const yValue = d => d.ConfirmCount;
  const circleRadius = 6;
  const yAxisLabel = 'SuspectedCount';
  const margin = {top:50, right:40, bottom: 60, left: 80};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  		.domain(extent(data, xValue))
  		.range([0, innerWidth])
  		.nice();
  
  const yScale = scaleLinear()
  		//.domain([0,1000])
  		.domain(extent(data, yValue))
  		.range([innerHeight, 0])
  		.nice();
  
  const yAxis = axisLeft(yScale)
  		.tickSize(-innerWidth)
  		.tickPadding(10);
  
  const g = svg.append('g')
  		.attr('transform', 'translate('+margin.left+', '+margin.top+')');
  
  const xAxisTickFormat = number => format('.3s')(number).replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
  							// .tickFormat(xAxisTickFormat)
  							.tickSize(-innerHeight)
  							.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -60)
  	.attr('x', -innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', 'translate(0,'+innerHeight+')');
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 40)
  	.attr('x', innerWidth/2-20)
    .attr('fill', 'black')
  	.text(xAxisLabel);
  
	g.selectAll('circle').data(data)
	.enter().append('circle')
	.attr('cy', d => yScale(yValue(d)))
	.attr('cx', d => xScale(xValue(d)))
	.attr('r', circleRadius);
 
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
//  g.append('path')
//  	.attr('class', 'line-path')
//  	.attr('d', lineGenerator(data));
  
  g.append('text')
  	.attr('class', 'title-label')
  	.attr('y', -10)
  	.text(title);
};

csv('data.csv').then(data => {
	data.forEach(d => {
    //console.log(data);
  	d.Time = new Date(d.Time);
    d.ConfirmCount = +d.ConfirmCount;
  });
  render(data);
});